Learn R Programming

aNCA (version 0.1.0)

.compress_range: Compresses a numeric vector into the simplest possible character string that, when evaluated, will create the same numeric vector.

Description

Compresses a numeric vector into the simplest possible character string that, when evaluated, will create the same numeric vector.

Usage

.compress_range(range_vector)

Value

simplest possible character string representing provided vector

Arguments

range_vector

numeric vector with numbers to compress into string