Learn R Programming

aNCA (version 0.1.0)

add_qmd_table: Helper to create a Quarto code chunk for a table

Description

Used internally to format a table chunk for Quarto documents.

Usage

add_qmd_table(table_expr)

Value

Character vector for Quarto code chunk.

Arguments

table_expr

Expression for table.