Takes in tables with existing and incoming selections and exclusions, finds any overlap and differences, edits the ruleset table accordingly.
check_slope_rule_overlap(existing, new, slope_groups, .keep = FALSE)Data frame with full ruleset, adjusted for new rules.
Data frame with existing selections and exclusions.
Data frame with new rule to be added or removed.
List with column names that define the groups.
Whether to force keep fully overlapping rulesets. If FALSE, it will be assumed that the user wants to remove rule if new range already exists in the dataset. If TRUE, in that case full range will be kept.