Compresses a numeric vector into the simplest possible character string that, when evaluated, will create the same numeric vector.
.compress_range(range_vector)simplest possible character string representing provided vector
numeric vector with numbers to compress into string