PKNCA_impute_method_start_c1: This function imputes the start concentration using the first concentration after dose
Description
This function imputes the start concentration using the first concentration after dose
Usage
PKNCA_impute_method_start_c1(conc, time, start, end, ..., options = list())
Value
A data frame with imputed start concentration.
Arguments
conc
Numeric vector of concentrations.
time
Numeric vector of times corresponding to the concentrations.
start
Numeric value indicating the start/dose time.
end
Numeric value indicating the end time.
...
Additional arguments (currently not used).
options
List of options (currently not used).
Details
This function adheres to the structure required by the PKNCA package to work with its
functionalities.For more information, see the
PKNCA Data Imputation Vignette.