Add a new version to an existing versioned settings list
Source:R/settings_versioned.R
add_settings_version.RdPrepends a new version entry so it becomes the current version.
The previous current entry moves to the previous list.
Arguments
- versions
Existing list of version entries.
- new_version
A single version entry (from
create_settings_version()).