The function converts a numeric value and its associated time unit into ISO 8601 duration string.
convert_to_iso8601_duration(value, unit)A character string representing the duration in ISO 8601 format.
A numeric value representing the time/duration.
A character string representing the unit of the time/duration.
It is a sensitive function that assumes that a valid time unit is given by the user. That means that if other units starting with 'y', 'm', 'w', 'd', 'h', or 's' are provided, it will make a naive guess that it refers to a time unit as year, month, week, day, hour, sec...