This function processes the results from a PKNCA and exports them into CDISC compliant datasets. Attention: All parameters that do no match pptest dataframe will be lost in this pipeline!
Usage
export_cdisc(res_nca, grouping_vars = character(0))This function processes the results from a PKNCA and exports them into CDISC compliant datasets. Attention: All parameters that do no match pptest dataframe will be lost in this pipeline!
export_cdisc(res_nca, grouping_vars = character(0))