Generate a session script from a settings YAML file
Source:R/get_session_code.R
get_settings_code.RdReads a settings YAML file and generates an R script that can reproduce the session. Mapping, filters, ratio table, and units are all read from the YAML.
Usage
get_settings_code(
settings_file_path,
data_path,
output_path = "settings_code.R",
template_path = system.file("www/templates/script_template.R", package = "aNCA")
)