This function returns a blank Plotly plot with optional annotation text. It ensures that when no valid data is available, a meaningful placeholder plot is displayed instead of causing an error.
Details
Parses annotations in the context of data. Special characters and syntax are substituted by actual data and/or substituted for format that is better parsed via rendering functions (e.g. plotly).
\ncharacter is substituted for<br>tag in order to add new lines in rendered image.$COLNAMEis parsed to provide unique data value from the mentioned column.!COLNAMEis parsed to providelabelattribute for a given column name. If any values are missing from the provided data, they are substituted forERRstring.