powered by
This function translates a character vector of terms from one nomenclature to another using a mapping file.
translate_terms( input_terms, mapping_col = "PKNCA", target_col = "PPTESTCD", metadata = metadata_nca_parameters )
A character vector of translated terms. Input terms not available in mapping_col will be returned with the same value.
A character vector of terms to be translated.
Character indicating the column name in the metadata file of the input terms. Default is "PKNCA".
Character indicating the column name in the metadata file of the target terms. Default is "PPTESTCD".
Dataset used to do the mapping that contains the mapping and target columns.
input_terms <- c("adj.r.squared", "ae", "nonexistent_term") translate_terms(input_terms)
Run the code above in your browser using DataLab