Writes a list of version entries to a YAML file in the versioned
format. The first entry becomes current, the rest go under
previous.
Arguments
- versions
A list of version entries (as returned by
create_settings_version()).- path
Character string with the output file path.